==> openimis_be_api_fhir_r4-1.6.0-py3-none-any.whl: api_fhir_r4/tests/test_api_communication.py <==
import json
import os

from rest_framework import status
from rest_framework.test import APITestCase

from api_fhir_r4.configurations import GeneralConfiguration, R4CommunicationRequestConfig as Config
from api_fhir_r4.tests import GenericFhirAPITestMixin
from api_fhir_r4.tests import LocationTestMixin
from api_fhir_r4.tests.utils import load_and_replace_json

from api_fhir_r4.tests.mixin.logInMixin import LogInMixin
from api_fhir_r4.utils import TimeUtils
from claim.models import Claim, ClaimItem, ClaimService, Feedback
from claim.test_helpers import create_test_claim_admin
from core import datetime
from insuree.test_helpers import create_test_insuree
from location.models import HealthFacility
from medical.models import Diagnosis
from medical.test_helpers import create_test_item, create_test_service
from location.test_helpers import create_test_village


class CommunicationAPITests(GenericFhirAPITestMixin, APITestCase, LogInMixin):
    base_url = GeneralConfiguration.get_base_url() + 'Communication/'
    _test_json_path = "/test/test_communication.json"

    _test_json_path_credentials = "/test/test_login.json"
    _test_request_data_credentials = None
    _test_json_path_with_code_reference = "/test/test_communication_with_code_reference.json"

    # feedback expected data
    _TEST_FEE_UUID = "612a1e12-ce44-4632-90a8-129ec714ec59"
    _TEST_CARE_RENDERED = False
    _TEST_PAYMENT_ASKED = True
    _TEST_DRUG_PRESCRIBED = True
    _TEST_DRUG_RECEIVED = False
    _TEST_ASESSMENT = '3'

    # claim data
    _TEST_CLAIM_CODE = 'codeTest'
    _TEST_CLAIM_UUID = "7ac646cb-d3cd-4660-baeb-ee34ecf0354e"
    _TEST_STATUS = Claim.STATUS_ENTERED
    _TEST_STATUS_DISPLAY = "entered"
    _TEST_OUTCOME = "queued"
    _TEST_ADJUSTMENT = "adjustment"
    _TEST_DATE_PROCESSED = "2010-11-16T00:00:00"
    _TEST_APPROVED = 1000.00
    _TEST_REJECTION_REASON = 0
    _TEST_VISIT_TYPE = "O"

    # claim item data
    _TEST_ITEM_CODE = "iCode"
    _TEST_ITEM_UUID = "e2bc1546-390b-4d41-8571-632ecf7a0936"
    _TEST_ITEM_STATUS = Claim.STATUS_ENTERED
    _TEST_ITEM_QUANTITY = 20
    _TEST_ITEM_PRICE = 10.0
    _TEST_ITEM_REJECTED_REASON = 0

    # claim service data
    _TEST_SERVICE_CODE = "sCode"
    _TEST_SERVICE_UUID = "a17602f4-e9ff-4f42-a6a4-ccefcb23b4d6"
    _TEST_SERVICE_STATUS = Claim.STATUS_ENTERED
    _TEST_SERVICE_QUANTITY = 1
    _TEST_SERVICE_PRICE = 800
    _TEST_SERVICE_REJECTED_REASON = 0

    _TEST_ID = 9999
    _PRICE_ASKED = 1000
    _PRICE_APPROVED = 1000
    _ADMIN_AUDIT_USER_ID = 1

    _TEST_ITEM_AVAILABILITY = True

    _TEST_ITEM_TYPE = 'D'
    _TEST_SERVICE_TYPE = 'D'

    # insuree and claim admin data
    _TEST_INSUREE_UUID = "76aca309-f8cf-4890-8f2e-b416d78de00b"
    _TEST_INSUREE_CHFID = "999000001"
    _TEST_CLAIM_ADMIN_UUID = "044c33d1-dbf3-4d6a-9924-3797b461e535"

    # hf test data
    _TEST_HF_ID = 10000
    _TEST_HF_UUID = "6d0eea8c-62eb-11ea-94d6-c36229a16c2f"
    _TEST_HF_CODE = "12345678"
    _TEST_HF_NAME = "TEST_NAME"
    _TEST_HF_LEVEL = "H"
    _TEST_HF_LEGAL_FORM = "G"
    _TEST_ADDRESS = "TEST_ADDRESS"
    _TEST_PHONE = "133-996-476"
    _TEST_FAX = "1-408-999 8888"
    _TEST_EMAIL = "TEST@TEST.com"
    sub_str = {}
    test_insuree = None
    test_claim_admin = None
    test_hf = None
    test_village = None
    test_claim = None
    test_item = None
    test_service = None
    def setUp(self):
        super(CommunicationAPITests, self).setUp()
        self._test_request_data=load_and_replace_json(self._test_json_path,self.sub_str)
        self.get_or_create_user_api()
        self.test_insuree = create_test_insuree()
        self.test_village = self.test_insuree.current_village or self.test_insuree.family.location
        self.test_hf = self.create_test_health_facility()
        self.test_claim_admin = create_test_claim_admin( custom_props={'health_facility_id': self.test_hf.id})
        self.test_claim = self.create_test_claim()
        self.test_item = self.create_test_claim_item()
        self.test_service = self.create_test_claim_service()

        self.sub_str[self._TEST_INSUREE_UUID]=self.test_insuree.uuid
        self.sub_str[self._TEST_INSUREE_CHFID]=self.test_insuree.chf_id
        self.sub_str[self._TEST_CLAIM_ADMIN_UUID]=self.test_claim_admin.uuid
        self.sub_str[self._TEST_CLAIM_UUID]=self.test_claim.uuid
        self.sub_str[self._TEST_HF_UUID]=self.test_hf.uuid




    def create_test_claim_item(self):
        item = ClaimItem()
        item.item = create_test_item(
            self._TEST_ITEM_TYPE,
            custom_props={"code": self._TEST_ITEM_CODE}
        )
        item.claim = self.test_claim
        item.status = self._TEST_ITEM_STATUS
        item.qty_approved = self._TEST_ITEM_QUANTITY
        item.qty_provided = self._TEST_ITEM_QUANTITY
        item.rejection_reason = self._TEST_ITEM_REJECTED_REASON
        item.availability = self._TEST_ITEM_AVAILABILITY
        item.price_asked = self._TEST_ITEM_PRICE
        item.price_approved = self._TEST_ITEM_PRICE
        item.audit_user_id = self._ADMIN_AUDIT_USER_ID
        item.save()
        return item

    def create_test_claim_service(self):
        service = ClaimService()
        service.service = create_test_service(
            self._TEST_SERVICE_TYPE,
            custom_props={"code": self._TEST_SERVICE_CODE}
        )
        service.claim = self.test_claim
        service.status = self._TEST_SERVICE_STATUS
        service.qty_approved = self._TEST_SERVICE_QUANTITY
        service.qty_provided = self._TEST_SERVICE_QUANTITY
        service.rejection_reason = self._TEST_SERVICE_REJECTED_REASON
        service.availability = self._TEST_ITEM_AVAILABILITY
        service.price_asked = self._TEST_SERVICE_PRICE
        service.price_approved = self._TEST_SERVICE_PRICE
        service.audit_user_id = self._ADMIN_AUDIT_USER_ID
        service.save()
        return service

    def create_test_health_facility(self):
        hf = HealthFacility()
        hf.id = self._TEST_HF_ID
        hf.uuid = self._TEST_HF_UUID
        hf.code = self._TEST_HF_CODE
        hf.name = self._TEST_HF_NAME
        hf.level = self._TEST_HF_LEVEL
        hf.legal_form_id = self._TEST_HF_LEGAL_FORM
        hf.address = self._TEST_ADDRESS
        hf.phone = self._TEST_PHONE
        hf.fax = self._TEST_FAX
        hf.email = self._TEST_EMAIL
        hf.location = self.test_village.parent.parent
        hf.offline = False
        hf.audit_user_id = -1
        hf.save()
        return hf

    def create_test_claim(self):
        imis_claim = Claim()
        imis_claim.id = self._TEST_ID
        imis_claim.code = self._TEST_CLAIM_CODE
        imis_claim.status = self._TEST_STATUS
        imis_claim.adjustment = self._TEST_ADJUSTMENT
        imis_claim.date_processed = TimeUtils.str_to_date(self._TEST_DATE_PROCESSED)
        imis_claim.approved = self._TEST_APPROVED
        imis_claim.rejection_reason = self._TEST_REJECTION_REASON
        imis_claim.insuree = self.test_insuree
        imis_claim.health_facility = self.test_hf
        imis_claim.icd = Diagnosis(code='ICD00I')
        imis_claim.icd.audit_user_id = self._ADMIN_AUDIT_USER_ID
        imis_claim.icd.save()
        imis_claim.audit_user_id = self._ADMIN_AUDIT_USER_ID
        imis_claim.icd.date_from = datetime.date(2018, 12, 12)
        imis_claim.date_from = datetime.date(2018, 12, 12)
        imis_claim.date_claimed = datetime.date(2018, 12, 14)
        imis_claim.visit_type = self._TEST_VISIT_TYPE
        imis_claim.admin = self.test_claim_admin
        imis_claim.save()
        return imis_claim



    def _get_json_of_communication_with_code_reference(self):
        dir_path = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
        return json.loads(
            open(dir_path + self._test_json_path_with_code_reference).read()
            )

    def test_post_should_create_correctly(self):
        
        response = self.client.post(
            GeneralConfiguration.get_base_url() + 'login/', data=self._test_request_data_credentials, format='json'
        )
        response_json = response.json()
        token = response_json["token"]
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        headers = {
            "Content-Type": "application/json",
            'HTTP_AUTHORIZATION': f"Bearer {token}"
        }


        dataset = [
            load_and_replace_json(self._test_json_path, self.sub_str),
            load_and_replace_json(self._test_json_path_with_code_reference, self.sub_str),
        ]

        for data in dataset:
            response = self.client.post(self.base_url, data=data, format='json', **headers)

            if False:#FIXME static data gets feedback exists, 
                self.assertEqual(response.status_code, status.HTTP_201_CREATED, response.json())
                self.assertIsNotNone(response.content)
                response_json = response.json()
                self.assertEqual(len(response_json['payload']), 5)
                for payload in response_json['payload']:
                    code = payload['extension'][0]['valueCodeableConcept']['coding'][0]['code']
                    content_string = payload['contentString']
                    if code != Config.get_fhir_asessment_code():
                        bool_value = self._convert_bool_value(content_string)
                    if code == Config.get_fhir_care_rendered_code():
                        self.assertEqual(self._TEST_CARE_RENDERED, bool_value, f'code {code}: {content_string}')
                    elif code == Config.get_fhir_payment_asked_code():
                        self.assertEqual(self._TEST_PAYMENT_ASKED, bool_value, f'code {code}: {content_string}')
                    elif code == Config.get_fhir_drug_prescribed_code():
                        self.assertEqual(self._TEST_DRUG_PRESCRIBED, bool_value, f'code {code}: {content_string}')
                    elif code == Config.get_fhir_drug_received_code():
                        self.assertEqual(self._TEST_DRUG_RECEIVED, bool_value, f'code {code}: {content_string}')
                    elif code == Config.get_fhir_asessment_code():
                        self.assertEqual(self._TEST_ASESSMENT, content_string, f'code {code}: {content_string}')

        
        claim = Claim.objects.get(uuid=str(self.test_claim.uuid))
        self.assertEqual(claim.feedback_status, Claim.FEEDBACK_DELIVERED)
        self.assertTrue(claim.feedback_available)
        self.assertIsNotNone(claim.feedback)
        if False:#FIXME
            self.assertEqual(claim.feedback.uuid.lower(), response_json['identifier'][0]['value'].lower())
            self.assertEqual(claim.uuid.lower(), response_json['about'][0]['identifier']['value'].lower())



    def _convert_bool_value(self, fhir_content_string):
        if fhir_content_string == "yes":
            return True
        if fhir_content_string == "no":
            return False
        return None

==> openimis_be_api_fhir_r4-1.8.1-py3-none-any.whl: api_fhir_r4/tests/test_api_communication.py <==
import json
import os

from rest_framework import status
from rest_framework.test import APITestCase

from api_fhir_r4.configurations import GeneralConfiguration, R4CommunicationRequestConfig as Config
from api_fhir_r4.tests import GenericFhirAPITestMixin
from api_fhir_r4.tests import LocationTestMixin
from api_fhir_r4.tests.utils import load_and_replace_json

from api_fhir_r4.tests.mixin.logInMixin import LogInMixin
from api_fhir_r4.utils import TimeUtils
from claim.models import Claim, ClaimItem, ClaimService, Feedback
from claim.test_helpers import create_test_claim_admin
from core import datetime
from insuree.test_helpers import create_test_insuree
from location.models import HealthFacility
from medical.models import Diagnosis
from medical.test_helpers import create_test_item, create_test_service
from location.test_helpers import create_test_village, create_test_health_facility


class CommunicationAPITests(GenericFhirAPITestMixin, APITestCase, LogInMixin):
    base_url = GeneralConfiguration.get_base_url() + 'Communication/'
    _test_json_path = "/test/test_communication.json"

    _test_json_path_credentials = "/test/test_login.json"
    _test_request_data_credentials = None
    _test_json_path_with_code_reference = "/test/test_communication_with_code_reference.json"

    # feedback expected data
    _TEST_FEE_UUID = "612a1e12-ce44-4632-90a8-129ec714ec59"
    _TEST_CARE_RENDERED = False
    _TEST_PAYMENT_ASKED = True
    _TEST_DRUG_PRESCRIBED = True
    _TEST_DRUG_RECEIVED = False
    _TEST_ASESSMENT = '3'

    # claim data
    _TEST_CLAIM_CODE = 'codeTest'
    _TEST_CLAIM_UUID = "7ac646cb-d3cd-4660-baeb-ee34ecf0354e"
    _TEST_STATUS = Claim.STATUS_ENTERED
    _TEST_STATUS_DISPLAY = "entered"
    _TEST_OUTCOME = "queued"
    _TEST_ADJUSTMENT = "adjustment"
    _TEST_DATE_PROCESSED = "2010-11-16T00:00:00"
    _TEST_APPROVED = 1000.00
    _TEST_REJECTION_REASON = 0
    _TEST_VISIT_TYPE = "O"

    # claim item data
    _TEST_ITEM_CODE = "iCode"
    _TEST_ITEM_UUID = "e2bc1546-390b-4d41-8571-632ecf7a0936"
    _TEST_ITEM_STATUS = Claim.STATUS_ENTERED
    _TEST_ITEM_QUANTITY = 20
    _TEST_ITEM_PRICE = 10.0
    _TEST_ITEM_REJECTED_REASON = 0

    # claim service data
    _TEST_SERVICE_CODE = "sCode"
    _TEST_SERVICE_UUID = "a17602f4-e9ff-4f42-a6a4-ccefcb23b4d6"
    _TEST_SERVICE_STATUS = Claim.STATUS_ENTERED
    _TEST_SERVICE_QUANTITY = 1
    _TEST_SERVICE_PRICE = 800
    _TEST_SERVICE_REJECTED_REASON = 0

    _TEST_ID = 9999
    _PRICE_ASKED = 1000
    _PRICE_APPROVED = 1000
    _ADMIN_AUDIT_USER_ID = 1

    _TEST_ITEM_AVAILABILITY = True

    _TEST_ITEM_TYPE = 'D'
    _TEST_SERVICE_TYPE = 'D'

    # insuree and claim admin data
    _TEST_INSUREE_UUID = "76aca309-f8cf-4890-8f2e-b416d78de00b"
    _TEST_INSUREE_CHFID = "999000001"
    _TEST_CLAIM_ADMIN_UUID = "044c33d1-dbf3-4d6a-9924-3797b461e535"

    # hf test data
    _TEST_HF_ID = 10000
    _TEST_HF_UUID = "6d0eea8c-62eb-11ea-94d6-c36229a16c2f"
    _TEST_HF_CODE = "12345678"
    _TEST_HF_NAME = "TEST_NAME"
    _TEST_HF_LEVEL = "H"
    _TEST_HF_LEGAL_FORM = "G"
    _TEST_ADDRESS = "TEST_ADDRESS"
    _TEST_PHONE = "133-996-476"
    _TEST_FAX = "1-408-999 8888"
    _TEST_EMAIL = "TEST@TEST.com"
    sub_str = {}
    test_insuree = None
    test_claim_admin = None
    test_hf = None
    test_village = None
    test_claim = None
    test_item = None
    test_service = None
    def setUp(self):
        super(CommunicationAPITests, self).setUp()
        self._test_request_data=load_and_replace_json(self._test_json_path,self.sub_str)
        self.get_or_create_user_api()
        self.test_insuree = create_test_insuree()
        self.test_village = self.test_insuree.current_village or self.test_insuree.family.location
        self.test_hf = self.create_test_hf()
        self.test_claim_admin = create_test_claim_admin( custom_props={'health_facility_id': self.test_hf.id})
        self.test_claim = self.create_test_claim()
        self.test_item = self.create_test_claim_item()
        self.test_service = self.create_test_claim_service()

        self.sub_str[self._TEST_INSUREE_UUID]=self.test_insuree.uuid
        self.sub_str[self._TEST_INSUREE_CHFID]=self.test_insuree.chf_id
        self.sub_str[self._TEST_CLAIM_ADMIN_UUID]=self.test_claim_admin.uuid
        self.sub_str[self._TEST_CLAIM_UUID]=self.test_claim.uuid
        self.sub_str[self._TEST_HF_UUID]=self.test_hf.uuid
        self._TEST_HF_UUID=self.test_hf.uuid
        self._TEST_HF_ID=self.test_hf.id



    def create_test_claim_item(self):
        item = ClaimItem()
        item.item = create_test_item(
            self._TEST_ITEM_TYPE,
            custom_props={"code": self._TEST_ITEM_CODE}
        )
        item.claim = self.test_claim
        item.status = self._TEST_ITEM_STATUS
        item.qty_approved = self._TEST_ITEM_QUANTITY
        item.qty_provided = self._TEST_ITEM_QUANTITY
        item.rejection_reason = self._TEST_ITEM_REJECTED_REASON
        item.availability = self._TEST_ITEM_AVAILABILITY
        item.price_asked = self._TEST_ITEM_PRICE
        item.price_approved = self._TEST_ITEM_PRICE
        item.audit_user_id = self._ADMIN_AUDIT_USER_ID
        item.save()
        return item

    def create_test_claim_service(self):
        service = ClaimService()
        service.service = create_test_service(
            self._TEST_SERVICE_TYPE,
            custom_props={"code": self._TEST_SERVICE_CODE}
        )
        service.claim = self.test_claim
        service.status = self._TEST_SERVICE_STATUS
        service.qty_approved = self._TEST_SERVICE_QUANTITY
        service.qty_provided = self._TEST_SERVICE_QUANTITY
        service.rejection_reason = self._TEST_SERVICE_REJECTED_REASON
        service.availability = self._TEST_ITEM_AVAILABILITY
        service.price_asked = self._TEST_SERVICE_PRICE
        service.price_approved = self._TEST_SERVICE_PRICE
        service.audit_user_id = self._ADMIN_AUDIT_USER_ID
        service.save()
        return service

    def create_test_hf(self):
        hf = create_test_health_facility(
            self._TEST_HF_CODE,
            self.test_village.parent.parent.id,
            custom_props = {
                'name': self._TEST_HF_NAME,
                'level':self._TEST_HF_LEVEL,
                'legal_form_id':self._TEST_HF_LEGAL_FORM,
                'address':self._TEST_ADDRESS,
                'phone':self._TEST_PHONE,
                'fax':self._TEST_FAX,
                'email':self._TEST_EMAIL,
            }
        )
        return hf

    def create_test_claim(self):
        imis_claim = Claim()
        imis_claim.id = self._TEST_ID
        imis_claim.code = self._TEST_CLAIM_CODE
        imis_claim.status = self._TEST_STATUS
        imis_claim.adjustment = self._TEST_ADJUSTMENT
        imis_claim.date_processed = TimeUtils.str_to_date(self._TEST_DATE_PROCESSED)
        imis_claim.approved = self._TEST_APPROVED
        imis_claim.rejection_reason = self._TEST_REJECTION_REASON
        imis_claim.insuree = self.test_insuree
        imis_claim.health_facility = self.test_hf
        imis_claim.icd = Diagnosis(code='ICD00I', name="test icd")
        imis_claim.icd.audit_user_id = self._ADMIN_AUDIT_USER_ID
        imis_claim.icd.save()
        imis_claim.audit_user_id = self._ADMIN_AUDIT_USER_ID
        imis_claim.icd.date_from = datetime.date(2018, 12, 12)
        imis_claim.date_from = datetime.date(2018, 12, 12)
        imis_claim.date_claimed = datetime.date(2018, 12, 14)
        imis_claim.visit_type = self._TEST_VISIT_TYPE
        imis_claim.admin = self.test_claim_admin
        imis_claim.save()
        return imis_claim



    def _get_json_of_communication_with_code_reference(self):
        dir_path = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
        return json.loads(
            open(dir_path + self._test_json_path_with_code_reference).read()
            )

    def test_post_should_create_correctly(self):
        
        response = self.client.post(
            GeneralConfiguration.get_base_url() + 'login/', data=self._test_request_data_credentials, format='json'
        )
        response_json = response.json()
        token = response_json["token"]
        self.assertEqual(response.status_code, status.HTTP_200_OK)
        headers = {
            "Content-Type": "application/json",
            'HTTP_AUTHORIZATION': f"Bearer {token}"
        }


        dataset = [
            load_and_replace_json(self._test_json_path, self.sub_str),
            load_and_replace_json(self._test_json_path_with_code_reference, self.sub_str),
        ]

        for data in dataset:
            response = self.client.post(self.base_url, data=data, format='json', **headers)

            if False:#FIXME static data gets feedback exists, 
                self.assertEqual(response.status_code, status.HTTP_201_CREATED, response.json())
                self.assertIsNotNone(response.content)
                response_json = response.json()
                self.assertEqual(len(response_json['payload']), 5)
                for payload in response_json['payload']:
                    code = payload['extension'][0]['valueCodeableConcept']['coding'][0]['code']
                    content_string = payload['contentString']
                    if code != Config.get_fhir_asessment_code():
                        bool_value = self._convert_bool_value(content_string)
                    if code == Config.get_fhir_care_rendered_code():
                        self.assertEqual(self._TEST_CARE_RENDERED, bool_value, f'code {code}: {content_string}')
                    elif code == Config.get_fhir_payment_asked_code():
                        self.assertEqual(self._TEST_PAYMENT_ASKED, bool_value, f'code {code}: {content_string}')
                    elif code == Config.get_fhir_drug_prescribed_code():
                        self.assertEqual(self._TEST_DRUG_PRESCRIBED, bool_value, f'code {code}: {content_string}')
                    elif code == Config.get_fhir_drug_received_code():
                        self.assertEqual(self._TEST_DRUG_RECEIVED, bool_value, f'code {code}: {content_string}')
                    elif code == Config.get_fhir_asessment_code():
                        self.assertEqual(self._TEST_ASESSMENT, content_string, f'code {code}: {content_string}')

        
        claim = Claim.objects.get(uuid=str(self.test_claim.uuid))
        self.assertEqual(claim.feedback_status, Claim.FEEDBACK_DELIVERED)
        self.assertTrue(claim.feedback_available)
        self.assertIsNotNone(claim.feedback)
        if False:#FIXME
            self.assertEqual(claim.feedback.uuid.lower(), response_json['identifier'][0]['value'].lower())
            self.assertEqual(claim.uuid.lower(), response_json['about'][0]['identifier']['value'].lower())



    def _convert_bool_value(self, fhir_content_string):
        if fhir_content_string == "yes":
            return True
        if fhir_content_string == "no":
            return False
        return None
